@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-extensions-manager-ui-extension.c,v 1.5 2005/04/19 11:30:17 chpe Exp $
+ *  $Id: ephy-extensions-manager-ui-extension.c,v 1.6 2005/12/02 12:50:17 chpe Exp $
  */
 
 #include "config.h"
@@ -157,8 +157,6 @@ display_cb (GtkAction *action,
 					   (gpointer *) &priv->dialog);
 	}
 
-	ephy_dialog_set_parent (EPHY_DIALOG (priv->dialog),
-				GTK_WIDGET (window));
 	ephy_dialog_show (EPHY_DIALOG (priv->dialog));
 }
 
